/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hdds.scm.container;

/**
 * Signals that a container is missing from ContainerManager.
 */
public class ContainerNotFoundException extends ContainerException {

  public ContainerNotFoundException() {
    this("Container not found for unknown id");
  }

  /** Required by {@link org.apache.hadoop.ipc.RemoteException#unwrapRemoteException()}. */
  public ContainerNotFoundException(String message) {
    super(message, ResultCodes.CONTAINER_NOT_FOUND);
  }

  public ContainerNotFoundException(ContainerID containerID) {
    this("Container " +  containerID + " not found");
  }

  public static ContainerNotFoundException newInstanceForTesting() {
    return new ContainerNotFoundException("For testing");
  }
}
